parse_peer_caps

Function parse_peer_caps 

pub fn parse_peer_caps(list: &WirePropertyList) -> PeerCapabilities
Reads security caps from a PropertyList. Unknown or malformed values are silently treated as “empty” — a peer must not be able to throw us out of the SPDP process via a broken property.