SecurityProfileConfig

Struct SecurityProfileConfig 

pub struct SecurityProfileConfig {
    pub domain_id: u32,
    pub identity_ca_pem: PathBuf,
    pub identity_cert_pem: PathBuf,
    pub identity_key_pem: PathBuf,
    pub permissions_ca_pem: PathBuf,
    pub governance_p7s: PathBuf,
    pub permissions_p7s: PathBuf,
}
File-path-based configuration for a SecurityProfile.

All paths must be readable and contain the usual DDS-Security 1.2 file formats:

  • identity_ca_pem — PEM bundle of the identity CA
  • identity_cert_pem — PEM with the participant’s identity certificate
  • identity_key_pem — PKCS#8 PEM with the private key
  • permissions_ca_pem — PEM bundle of the permissions CA (often = identity_ca)
  • governance_p7s — CMS-signed governance XML (.p7s)
  • permissions_p7s — CMS-signed permissions XML (.p7s)

Fields

domain_id: u32

DDS domain id (decides the match in the governance).

identity_ca_pem: PathBuf

PEM bundle of the identity CA (trust anchors for remote certs).

identity_cert_pem: PathBuf

PEM with the identity cert of the local participant.

identity_key_pem: PathBuf

PKCS#8 PEM private key of the local participant.

permissions_ca_pem: PathBuf

PEM bundle of the permissions CA (signs governance/permissions).

governance_p7s: PathBuf

CMS-signed governance XML.

permissions_p7s: PathBuf

CMS-signed permissions XML.